# Generated by Django 3.1.8 on 2021-05-11 16:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('streamfield', '0002_gallery_stream'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Gallery',
        ),
    ]



from rest_framework import generics
from rest_framework.fields import SerializerMethodField
from rest_framework.permissions import AllowAny
from rest_framework.serializers import ModelSerializer
from rest_framework import serializers
from wagtail.users.models import UserProfile
from wagtail_rest_pack.exception.handler import custom_exception_handler
from django.contrib.auth import get_user_model

from wagtail_rest_pack.comments.content_type import create_content_type_id
from wagtail_rest_pack.comments.models import Comment


class PageAuthorUserProfileSerializer(serializers.ModelSerializer):
    class Meta:
        model = UserProfile
        fields = ['avatar']


class CommentAuthorSerializer(serializers.ModelSerializer):
    profile = PageAuthorUserProfileSerializer(source='wagtail_userprofile', read_only=True, required=False)

    class Meta:
        model = get_user_model()
        fields = ['is_staff', 'is_superuser', 'username', 'first_name', 'last_name', 'profile']


class GetCommentSerializer(ModelSerializer):
    children = SerializerMethodField('_get_children')
    author = CommentAuthorSerializer(source="created_by")
    updated_by = CommentAuthorSerializer()

    class Meta:
        model = Comment
        fields = ['id', 'parent', 'created_on', 'author', 'updated_on', 'updated_by', 'body', 'children']

    def _get_children(self, obj):
        children = Comment.objects.filter(parent_id=obj.id).order_by('created_on')
        serializer = GetCommentSerializer(children, many=True)
        return serializer.data


class ListCommentAPIView(generics.ListAPIView):
    """
    example: /?content_type=wagtailcore.Page&object_id=4
    """
    permission_classes = [AllowAny]
    serializer_class = GetCommentSerializer

    def get_queryset(self):
        object_id = self.request.query_params.get('object_id', None)
        content_type = self.request.query_params.get('content_type', None)
        content_type_id = create_content_type_id(object_id, content_type)
        return Comment.objects.filter(object_id=object_id, content_type_id=content_type_id, parent=None).order_by('created_on')

    def get_exception_handler(self):
        return custom_exception_handler



from django.utils.translation import gettext_lazy as _
from wagtail.core.fields import StreamField
from wagtail.snippets.models import register_snippet
from django.conf import settings
from django.db import models
from wagtail_rest_pack.custom_menu.serializers import LinkBlockSerializer
from wagtail_rest_pack.streamfield.containers import ContainersSerializer
from wagtail_rest_pack.custom_menu.serializers import LinkCategorySerializer
from wagtail_rest_pack.custom_menu.serializers import ChildrenLinksSerializer

default_names = [('default', 'default')]
choices = getattr(settings, "REST_PACK", {}).get('custom_menu', {'names': default_names}).get('names', default_names)

@register_snippet
class CustomMenu(models.Model):

    name = models.CharField(max_length=50, choices=choices, primary_key=True)
    stream = StreamField(block_types=[
        ContainersSerializer.block_definition([
            LinkBlockSerializer.block_definition(),
            LinkCategorySerializer.block_definition([
                LinkBlockSerializer.block_definition(),
                ChildrenLinksSerializer.block_definition(),
            ])
        ]),
        LinkBlockSerializer.block_definition(),
        LinkCategorySerializer.block_definition([
            LinkBlockSerializer.block_definition(),
            ChildrenLinksSerializer.block_definition(),
        ])
    ], default=[])

    def __str__(self):
        return str(dict((x, y) for x, y in choices)[self.name])

    class Meta:
        verbose_name = _('Menu')
        verbose_name_plural = _('Menus')



from rest_framework import serializers
from wagtail.core.blocks import RichTextBlock

from wagtail.core.templatetags.wagtailcore_tags import richtext as richtext_filter


def rich_text():
    return RichTextSerializer.block_definition()


class RichTextSerializer(serializers.Serializer):
    block_name = 'richtext'
    text = serializers.SerializerMethodField('get_text')

    @staticmethod
    def block_definition():
        features = ['h2', 'h3', 'italic', 'bold', 'ol', 'ul', 'hr', 'link',
                    'document-link', 'image', 'embed', 'code',
                    'superscript', 'subscript', 'strikethrough', 'blockquote']
        return RichTextSerializer.block_name, RichTextBlock(features=features,icon='doc-full')

    class Meta:
        fields = ('text',)

    def get_text(self, value):
        return richtext_filter(value.source)



from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models

from wagtail.snippets.models import register_snippet

@register_snippet
class Comment(models.Model):
    parent = models.ForeignKey('self', on_delete=models.CASCADE, related_name='children', blank=True, null=True)
    created_on = models.DateTimeField(auto_now_add=True, editable=False)
    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, editable=False, on_delete=models.SET_NULL, null=True, blank=True)
    updated_on = models.DateTimeField(auto_now_add=False, default=None, null=True, editable=True)
    updated_by = models.ForeignKey(settings.AUTH_USER_MODEL, editable=False, on_delete=models.SET_NULL, null=True, blank=True, related_name='updated_by')
    body = models.TextField(max_length=2000)

    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey('content_type', 'object_id', for_concrete_model=False)

    class Meta:
        ordering = ['created_on', 'created_by']

    def __str__(self):
        return 'Comment {}'.format(self.body)



# Generated by Django 3.2 on 2021-04-30 13:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('comments', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='comment',
            name='updated_on',
            field=models.DateTimeField(default=None, null=True),
        ),
    ]



# Generated by Django 3.2 on 2021-05-02 08:37

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('comments', '0002_comment_updated_on'),
    ]

    operations = [
        migrations.AddField(
            model_name='comment',
            name='updated_by',
            field=models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='updated_by', to=settings.AUTH_USER_MODEL),
        ),
    ]



from django.conf import settings
from rest_framework import serializers
from rest_framework.fields import Field
from rest_framework.serializers import ModelSerializer
from wagtail.core.models import Page
from wagtail.images.api.fields import ImageRenditionField
from wagtail_rest_pack.streamfield.serializers import SettingsStreamFieldSerializer


class BannerSerializer(serializers.Serializer):
    spec = getattr(settings, 'IMAGE_BANNER_RENDERITION', 'fill-300x200')
    title = serializers.CharField(source='banner_title', required=False)
    subtitle = serializers.CharField(source='banner_subtitle', required=False)
    image = ImageRenditionField(spec, source='banner_image')
    class Meta:
        fields = ['title', 'subtitle', 'image',]

class ChildPageBannerSerializer(ModelSerializer):
    def __init__(self, *args, **kwargs):
        self.child_extra = kwargs.pop('child_extra', [])
        super(ChildPageBannerSerializer, self).__init__(*args,**kwargs)

    extra = serializers.SerializerMethodField('create_extra')
    banner = BannerSerializer(source='*')
    keywords = serializers.StringRelatedField(many=True)
    class Meta:
        model= Page
        fields=['id', 'slug', 'url', 'last_published_at', 'banner', 'keywords', 'extra']

    def create_extra(self, instance):
        ret = {}
        if 'stream' in self.child_extra:
            ret['stream'] = SettingsStreamFieldSerializer().to_representation(instance.stream)
        return ret

class BanneredChildrenSerializer(Field):

    def to_representation(self, value):
        request = self.context['request']
        order = request.query_params.get('order', '-last_published_at')
        child_extra = request.query_params.get('child_extra', '').split(',')
        qs = value
        if hasattr(value, 'specific'):
            qs = qs.specific()
        if order is not None and hasattr(qs, 'order_by'):
            qs = qs.order_by(order)
        qs = self.context['view'].paginate_queryset(qs)
        return ChildPageBannerSerializer(qs, child_extra=child_extra, many=True).data



# Generated by Django 3.2.3 on 2021-05-26 16:01

from django.db import migrations


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('taggit', '0003_taggeditem_add_unique_index'),
        ('custom_tag', '0002_delete_pagetag'),
    ]

    operations = [
        migrations.CreateModel(
            name='Tag',
            fields=[
            ],
            options={
                'verbose_name': 'Keyword',
                'verbose_name_plural': 'Keywords',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('taggit.tag',),
        ),
    ]






"""
Django settings for mysite project.

Generated by 'django-admin startproject' using Django 3.1.8.

For more information on this file, see
https://docs.djangoproject.com/en/3.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.1/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os

PROJECT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
BASE_DIR = os.path.dirname(PROJECT_DIR)


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/


SITE_ID = 1

IMAGE_LARGE_RENDERITION = 'width-1280'
IMAGE_SMALL_RENDERITION = 'width-480'
IMAGE_BANNER_RENDERITION = 'fill-300x200'


SECRET_KEY="xxxx"


INSTALLED_APPS = [
    'wagtail.contrib.forms',
    'wagtail.contrib.redirects',
    'wagtail.embeds',
    'wagtail.sites',
    'wagtail.users',
    'wagtail.snippets',
    'wagtail.documents',
    'wagtail.images',
    'wagtail.search',
    'wagtail.admin',
    'wagtail.core',

    'wagtail.api.v2',
    'rest_framework',
    'rest_framework.authtoken',

    'modelcluster',
    'taggit',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.sitemaps',
    'wagtail.contrib.modeladmin',

    'django',
    'wagtail',
    'wagtail_rest_pack.breadcrumps',
    'wagtail_rest_pack.page_banner',
    'wagtail_rest_pack.sitesettings',
    'wagtail_rest_pack.relations',
    'wagtail_rest_pack.comments',
    'wagtail_rest_pack.generic_forms',
    'wagtail_rest_pack.streamfield',
]


MIDDLEWARE = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
    'wagtail.contrib.redirects.middleware.RedirectMiddleware',
]
ROOT_URLCONF = 'demo.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(PROJECT_DIR, 'templates'),
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'mysite.wsgi.application'


# Database
# https://docs.djangoproject.com/en/3.1/ref/settings/#databases


# Password validation
# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.1/topics/i18n/

LANGUAGES = (
    ('en', 'English'),
    ('cs', 'Čeština'),
)
LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True

USE_TZ = True

STATICFILES_STORAGE = 'django.contrib.staticfiles.storage.ManifestStaticFilesStorage'
STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
STATIC_URL = '/static/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
MEDIA_URL = '/media/'





# Generated by Django 3.2.3 on 2021-10-03 15:27

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CustomMenu',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50)),
            ],
            options={
                'verbose_name': 'Menu',
                'verbose_name_plural': 'Menus',
            },
        ),
    ]



from rest_framework.serializers import Field
from wagtail.core.models import Page


class BreadcrumpSerializer(Field):
    def get_parent_or_none(self, page) -> Page or None:
        parent = page.get_parent()
        if parent is None:
            return None
        if parent.url is None:
            return None
        if parent.url == '/':
            return None
        return parent

    def to_representation(self, page: Page):
        parent = page
        while parent is not None:
            yield {
                'id': parent.id,
                'url': parent.url,
                'slug': parent.slug,
                'title': parent.title
            }
            parent = self.get_parent_or_none(parent)



# Generated by Django 3.2.3 on 2021-10-03 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0002_alter_custommenu_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='custommenu',
            name='id',
        ),
        migrations.AlterField(
            model_name='custommenu',
            name='name',
            field=models.CharField(choices=[('top', 'Horní menu'), ('footer', 'Patička')], max_length=50, primary_key=True, serialize=False),
        ),
    ]



from rest_framework import serializers
from django.utils.translation import gettext_lazy as _

from wagtail.images import get_image_model
from rest_framework.fields import Field
from wagtail.images.api.fields import ImageRenditionField
from django.conf import settings


class GalleryImageSerializer(serializers.ModelSerializer):
    image = serializers.SerializerMethodField('create_image')

    class Meta:
        model = get_image_model()
        fields = ['image',]

    def create_image(self, data):
        model = get_image_model()
        image = model.objects.get(id=data['id'])
        large_renderition = getattr(settings, 'IMAGE_LARGE_RENDERITION', 'width-1280')
        small_renderition = getattr(settings, 'IMAGE_BANNER_RENDERITION', 'fill-300x200')
        return {
            'id': data['id'],
            'title': image.title,
            'caption': image.caption,
            'large': ImageRenditionField(large_renderition).to_representation(image),
            'small': ImageRenditionField(small_renderition).to_representation(image),
        }





from wagtail.admin.edit_handlers import InlinePanel
from wagtail.api import APIField

from wagtail_rest_pack.sitesettings.serializers import SiteSettingsSerializer
from django.utils.translation import gettext as _


class SiteSettingsPanelMixin:
    site_settings_panels = [
        InlinePanel('carouselitems', label=_('Carousel Items'))
    ]

    api_fields = [
        APIField('carouselitems', SiteSettingsSerializer())
    ]



from rest_framework import generics
from rest_framework import serializers

from .models import PageTag


class TagSerializer(serializers.ModelSerializer):
    tag = serializers.StringRelatedField(source="tag__name")
    class Meta:
        model = PageTag
        fields = ['tag']


class TagViewset(generics.ListAPIView):
    model = PageTag
    queryset = PageTag.objects.values('tag__name').distinct() # todo lists all tags, I need a set, no duplicates plase :)
    serializer_class = TagSerializer



from rest_framework import generics
from rest_framework import serializers
from wagtail_rest_pack.streamfield.serializers import SettingsStreamFieldSerializer

from .models import CustomMenu


class CustomMenuSerializer(serializers.ModelSerializer):
    stream = SettingsStreamFieldSerializer()
    class Meta:
        model = CustomMenu
        fields = ['name', 'stream',]


class CustomMenuRetrieveSet(generics.RetrieveAPIView):
    model = CustomMenu
    lookup_field = 'name'
    queryset = CustomMenu.objects.all()
    serializer_class = CustomMenuSerializer



from rest_framework import serializers
from wagtail.core import blocks
from wagtail.core.blocks import StreamBlock
from django.utils.translation import gettext_lazy as _

from wagtail_rest_pack.streamfield.serializers import SettingsStreamFieldSerializer

from wagtail_rest_pack.streamfield.container import ContainerBlock, container_block


def containers_block(local_blocks):
    return ContainersSerializer.block_definition(local_blocks=local_blocks)


class ContainersSerializer(serializers.Serializer):
    block_name = 'containers'
    stream = SettingsStreamFieldSerializer()

    @staticmethod
    def block_definition(local_blocks):
        return ContainersSerializer.block_name, ContainersBlock(local_blocks=local_blocks, icon='container', label=_('More Columns'))

    class Meta:
        fields = ('stream',)


class ContainersBlock(blocks.StructBlock):

    def __init__(self, local_blocks, *args, **kwargs):
        super().__init__(local_blocks=[
            ('stream', StreamBlock(local_blocks=[
                container_block(local_blocks),
             ], label=_('Columns'))),
        ], **kwargs)



import requests
from rest_framework.exceptions import ValidationError
from wagtail_rest_pack.recaptcha.models import RecaptchaVerifier
from django.conf import settings
from wagtail_rest_pack.recaptcha.models import get_client_ip
from django.utils.translation import gettext as _


class GoogleRecaptchaVerifier(RecaptchaVerifier):
    def verify(self, request):
        captcha_rs = request.data.get('g-recaptcha-response')
        if captcha_rs is None:
            raise ValidationError(_('Recaptcha field is empty'))
        url = "https://www.google.com/recaptcha/api/siteverify"
        ip = get_client_ip(request)
        secret = getattr(settings, 'GOOGLE_RECAPTCHA_SECRET', None)
        assert secret is not None, ('Please, define GOOGLE_RECAPTCHA_SECRET in settings.')
        params = {
            'secret': secret,
            'response': captcha_rs,
            'remoteip': "localhost" if ip == "127.0.0.1" else ip
        }
        verify_rs = requests.get(url, params=params, verify=True)
        verify_rs = verify_rs.json()
        if not verify_rs.get("success", False):
            error = verify_rs.get('error-codes', None) or "Unspecified error."
            if isinstance(error, list):
                error = ",".join(error)
            raise ValidationError(_(f'Error while validating Recaptcha: {error}'), code="400")



from rest_framework import serializers
from wagtail.core import blocks
from wagtail.core.blocks import StreamBlock
from django.utils.translation import gettext_lazy as _

from wagtail_rest_pack.streamfield.serializers import SettingsStreamFieldSerializer


def container_block(local_blocks):
    return ContainerSerializer.block_definition(local_blocks=local_blocks)


class ContainerSerializer(serializers.Serializer):
    block_name = 'container'
    stream = SettingsStreamFieldSerializer()

    @staticmethod
    def block_definition(local_blocks):
        return ContainerSerializer.block_name, ContainerBlock(local_blocks=local_blocks, icon='doc-full', label=_('Column'))

    class Meta:
        fields = ('stream',)


class ContainerBlock(blocks.StructBlock):

    def __init__(self, local_blocks, *args, **kwargs):
        super().__init__(local_blocks=[
            ('stream', StreamBlock(local_blocks=local_blocks, label=_('Content of Column'))),
        ], **kwargs)



from rest_framework import serializers
from wagtail.core import blocks
from wagtail_rest_pack.generic_forms.actions.send_email import SendEmailAction
from wagtail_rest_pack.generic_forms.response.snack import ShowSnackResponse
from django.core.exceptions import ValidationError

from django.utils.translation import gettext_lazy as _
from wagtail_rest_pack.streamfield.richtext import RichTextSerializer
from wagtail_rest_pack.streamfield.serializers import SettingsStreamFieldSerializer


class OpenDialogSerializer(serializers.Serializer):
    type= 'form_open_dialog'
    title = serializers.CharField(max_length=40)
    text = SettingsStreamFieldSerializer()
    @staticmethod
    def block_definition() ->tuple:
        return OpenDialogSerializer.type, blocks.StructBlock(local_blocks=[
            ('title', blocks.TextBlock(required=True, help_text=_('title'), max_length=40)),
            ('text', blocks.StreamBlock([
                RichTextSerializer.block_definition()
            ]))
        ])

    class Meta:
        fields = ['title', 'text',]


class SubmitBlockSerializer(serializers.Serializer):
    block_name = 'form_submit'
    name = serializers.CharField(max_length=30)
    text = serializers.CharField(max_length=30)

    @staticmethod
    def block_definition():
        return SubmitBlockSerializer.block_name, SubmitBlock('submit')

    class Meta:
        fields = ['name', 'text',]

class RevealSubmitBlockSerializer(SubmitBlockSerializer):
    response = SettingsStreamFieldSerializer()
    action = SettingsStreamFieldSerializer()
    class Meta:
        fields = ['name', 'text', 'response', 'action',]

class SubmitBlock(blocks.StructBlock):

    def get_responses(self):
        return [
            OpenDialogSerializer.block_definition(),
            ShowSnackResponse.block_definition(),
        ]

    def get_actions(self):
        return [
            SendEmailAction.block_definition(),
        ]

    def __init__(self, *args, **kwargs):
        self.action_definitions = blocks.StreamBlock(self.get_actions(), min_num=1, max_num=1, label=_('Form action'))
        self.response_definition = blocks.StreamBlock(self.get_responses(), min_num=1, max_num=1, label=_('Form response'))
        super().__init__(local_blocks=[
            ('name', blocks.TextBlock(max_length=30, help_text=_('Technical name of a field, e.g. email_field'), label=_('Field name'), validators=[])),
            ('text', blocks.CharBlock(max_length=30, label=_('A text button label'))),
            ('action', self.action_definitions),
            ('response', self.response_definition)
        ], **kwargs)



from rest_framework import serializers
from wagtail.core import blocks
from wagtail_rest_pack.generic_forms.blocks.text_block import InputBlockSerializer
from wagtail_rest_pack.generic_forms.blocks.visibility import visibility_choices
from wagtail_rest_pack.streamfield.serializers import SettingsStreamFieldSerializer
from django.utils.translation import gettext_lazy as _


class GroupBlockSerializer(serializers.Serializer):
    block_name = 'form_group'
    name = serializers.CharField(max_length=80)
    row = serializers.BooleanField()
    required = serializers.ChoiceField(choices=visibility_choices)
    stream = SettingsStreamFieldSerializer()
    class Meta:
        fields = ('name', 'row', 'required', 'stream',)

    @staticmethod
    def block_definition():
        return GroupBlockSerializer.block_name, GroupBlock(stream_blocks=[
            InputBlockSerializer.block_definition()
        ])

    def validate(self, attrs):
        pass

class GroupBlock(blocks.StructBlock):

    def __init__(self, stream_blocks, **kwargs):
        self.stream_definition = blocks.StreamBlock(local_blocks=stream_blocks)
        local_blocks = [
            ('name', blocks.CharBlock(max_length=80)),
            ('row', blocks.BooleanBlock(required=False, default=False, label=_('Show on a single line'))),
            ('required', blocks.ChoiceBlock(choices=visibility_choices, default=visibility_choices[0][0], label=_('Condition of visibility'))),
            ('stream', self.stream_definition)
        ]
        super().__init__(local_blocks=local_blocks, **kwargs)




from django.db import models
from wagtail.core.models import Page


class RelationField:
    def __init__(self, name, serializer=None):
        self.name = name
        self.serializer = serializer

    def __hash__(self):
        return hash(self.name)

    def __repr__(self):
        return '<APIField {}>'.format(self.name)


class Relation(models.Model):
    from_page = models.ForeignKey(Page, related_name='from_page', on_delete=models.CASCADE)
    to_page = models.ForeignKey(Page, related_name='to_page', on_delete=models.CASCADE)

    class Meta:
        unique_together = ('from_page', 'to_page')



from wagtail.admin.edit_handlers import InlinePanel
from wagtail.api import APIField
from wagtail_rest_pack.page_banner.serializers import BanneredChildrenSerializer
from wagtail_rest_pack.relations.models import Relation

from wagtail_rest_pack.sitesettings.serializers import SiteSettingsSerializer
from django.utils.translation import gettext as _
from wagtail.core.models import Page


class RelationsMixin:
    api_fields = [
        APIField('relations', serializer=BanneredChildrenSerializer())
    ]

    @property
    def relations(self):
        return Page.objects.filter(id__in=Relation.objects.filter(to_page_id=self.id).values('from_page_id'))



from django.db import models
from modelcluster.models import ClusterableModel
from wagtail.admin.edit_handlers import FieldPanel, StreamFieldPanel
from wagtail.core.blocks import StreamBlock
from wagtail.core.fields import StreamField
from wagtail.snippets.models import register_snippet
from django.utils.translation import gettext_lazy as _
from wagtail.images.blocks import ImageChooserBlock
from wagtail.core import blocks

class GalleryImageBlock(blocks.StructBlock):
    def __init__(self, *args, **kwargs):
        super().__init__(local_blocks=[
            ('id', ImageChooserBlock(icon='image', label=_('Image'))),
        ], **kwargs)


@register_snippet
class Gallery(ClusterableModel):
    name = models.CharField(max_length=120, help_text=_('Gallery name'))
    stream = StreamField(block_types=[
        ('gallery_image', GalleryImageBlock()),
    ])
    panels = [
        FieldPanel('name'),
        StreamFieldPanel('stream'),
    ]

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Gallery')
        verbose_name_plural = _('Galleries')



# Generated by Django 3.1.8 on 2021-05-12 14:01

from django.db import migrations
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('streamfield', '0005_auto_20210512_1354'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gallery',
            name='stream',
            field=wagtail.core.fields.StreamField([('gallery_image', wagtail.core.blocks.StructBlock([('image2', wagtail.images.blocks.ImageChooserBlock())], icon='image', label='Image'))]),
        ),
    ]



# Generated by Django 3.2.3 on 2021-10-03 16:14

from django.db import migrations
import wagtail.core.blocks
import wagtail.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0005_alter_custommenu_content'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='custommenu',
            name='content',
        ),
        migrations.AddField(
            model_name='custommenu',
            name='stream',
            field=wagtail.core.fields.StreamField([('containers', wagtail.core.blocks.StructBlock([('stream', wagtail.core.blocks.StreamBlock([('container', wagtail.core.blocks.StructBlock([('stream', wagtail.core.blocks.StreamBlock([('linkblock', wagtail.core.blocks.StructBlock([('name', wagtail.core.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.core.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.core.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka')], label='The icon'))]))], label='Content of Column'))], icon='doc-full', label='Column'))], label='Columns'))], icon='container', label='More Columns')), ('linkblock', wagtail.core.blocks.StructBlock([('name', wagtail.core.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.core.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.core.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka')], label='The icon'))]))], default=[]),
        ),
    ]



from django.db.models.signals import post_save, post_delete
from wagtail.core.models import Page
from .index import indexUpdated
from .index import indexDeleted


def on_page_saved(sender, *args, **kwargs):
    instance = kwargs.get('instance', None)
    if instance is not None and issubclass(sender, Page):
        indexUpdated(**kwargs)

def on_page_delete(sender, *args, **kwargs):
    instance = kwargs.get('instance', None)
    if instance is not None and issubclass(sender, Page):
        indexDeleted(**kwargs)

def register_signal_handlers():
    post_save.connect(on_page_saved)
    post_delete.connect(on_page_delete)




from wagtail.core import blocks

from wagtail_rest_pack.generic_forms.actions.action import FormAction
from django.utils.translation import gettext as _


class SendEmailAction(FormAction):
    type = 'send_email'

    @staticmethod
    def block_definition() -> tuple:
        return SendEmailAction.type, blocks.StructBlock(local_blocks=[
            ('sender', blocks.CharBlock(max_length=50, label=_('Technical name of a field containing a sender email address'))),
            ('address', blocks.EmailBlock(max_length=150, label=_('A email address to which a email should be delived to')))
        ])



from django.db import models
from wagtail.admin.edit_handlers import FieldPanel
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtail.snippets.models import register_snippet
from wagtail.images import get_image_model_string
from wagtail.core.fields import RichTextField

from django.utils.translation import gettext as _

@register_snippet
class ImageSliderItem(models.Model):
    image = models.ForeignKey(get_image_model_string(), on_delete=models.PROTECT, blank=False, null=True, default=None)
    text = RichTextField(features=['h2', 'h3', 'bold', 'italic', 'link'], max_length=200, blank=False, default="",
                         help_text=_('Text'))

    panels = [
        FieldPanel('text'),
        ImageChooserPanel('image'),
    ]

    def __str__(self):
        return self.image.__str__() + " -> " + self.text

    class Meta:
        verbose_name = _('Carousel Item')
        verbose_name_plural = _('Carousel Items')
